import { getOpusListApi } from '@/services/task-api/opus';
import { MaterialTypeEnum } from '@/utils/constEnum';
import { SearchOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-components';
import { useRequest } from 'ahooks';
import { Affix, Button, Card, Col, DatePicker, Form, Input, Row, Select, Space, theme } from 'antd';
import moment from 'moment';
import { useEffect, useState } from 'react';
import style from './index.less';
import OpusRoll from './opusRoll';

const Opus: React.FC = () => {
  /**************************************/
  const { useToken } = theme;
  const { token } = useToken();
  const [form] = Form.useForm<TASKAPI.OpusList>();
  const [queryForm, setQueryForm] = useState<TASKAPI.OpusList>({ pageNum: 1, pageSize: 10 });
  const getOpusList = useRequest(getOpusListApi, { manual: true });
  const [data, setData] = useState<any[]>([]);
  /**************************************/

  useEffect(() => {
    getOpusList.runAsync(queryForm).then((res) => {
      if (res) {
        if (queryForm.pageNum === 1) {
          setData(res?.data?.records);
        } else {
          setData(data.concat(res?.data?.records));
        }
      }
    });
  }, [queryForm]);

  const onFinish = (data: any) => {
    const { taskTime, uploadTime, ...pre } = data;
    let newQueryForm = JSON.parse(JSON.stringify(queryForm));
    newQueryForm.pageNum = 1;
    if (taskTime) {
      newQueryForm.taskCreateStartTime = moment(taskTime[0]).format('YYYY-MM-DD');
      newQueryForm.taskCreateEndTime = moment(taskTime[1]).format('YYYY-MM-DD');
    } else {
      delete newQueryForm?.taskCreateStartTime;
      delete newQueryForm?.taskCreateEndTime;
    }
    if (uploadTime) {
      newQueryForm.uploadStartTime = moment(uploadTime[0]).format('YYYY-MM-DD');
      newQueryForm.uploadEndTime = moment(uploadTime[1]).format('YYYY-MM-DD');
    } else {
      delete newQueryForm?.uploadStartTime;
      delete newQueryForm?.uploadEndTime;
    }
    setQueryForm({ ...newQueryForm, ...pre });
  };

  // 下一页
  const loadMoreData = () => {
    setQueryForm({ ...queryForm, pageNum: queryForm.pageNum + 1 });
  };

  return (
    <PageContainer>
      <Card style={{ borderRadius: 8 }} bodyStyle={{ padding: 0 }}>
        <Space direction="vertical" style={{ width: '100%' }} size={0}>
          <Affix offsetTop={56}>
            <div
              style={{
                backgroundColor: token.colorBgBase,
                padding: token.paddingContentHorizontalLG,
                borderRadius: 8,
                borderBottom: `1px solid ${token.colorBorderSecondary}`,
              }}
            >
              <Form
                layout="inline"
                className="queryForm"
                name="basic"
                form={form}
                onFinish={onFinish}
              >
                <Row gutter={[0, 6]}>
                  <Col>
                    <Form.Item name="materialType">
                      <Select
                        placeholder="素材类型"
                        options={Object.keys(MaterialTypeEnum).map((key) => ({
                          label: (MaterialTypeEnum as any)[key],
                          value: key,
                        }))}
                      />
                    </Form.Item>
                  </Col>

                  <Col>
                    <Form.Item name="taskName">
                      <Input prefix={<SearchOutlined />} placeholder="搜索任务名称" />
                    </Form.Item>
                  </Col>

                  <Col>
                    <Form.Item name="taskTime">
                      <DatePicker.RangePicker
                        style={{ width: 250 }}
                        placeholder={['任务开始日期', '任务开始日期']}
                      />
                    </Form.Item>
                  </Col>

                  <Col>
                    <Form.Item name="uploadTime">
                      <DatePicker.RangePicker
                        style={{ width: 250 }}
                        placeholder={['上传开始日期', '上传开始日期']}
                      />
                    </Form.Item>
                  </Col>

                  <Col>
                    <Space>
                      <Button type="primary" htmlType="submit">
                        搜索
                      </Button>
                      <Button onClick={() => form.resetFields()}>重置</Button>
                    </Space>
                  </Col>
                </Row>
              </Form>
            </div>
          </Affix>

          <div style={{ padding: 19 }} className={style.weMaterial_left}>
            <OpusRoll
              data={data}
              total={getOpusList.data?.data?.total || 0}
              loading={getOpusList.loading}
              loadMore={loadMoreData}
            />
          </div>
        </Space>
      </Card>
    </PageContainer>
  );
};

export default Opus;
